@@ -1,5 +1,3 @@
-#![allow(clippy::uninlined_format_args)]
-
 use anyhow::{Context, Result};
 use clap::{Arg, ArgAction, ArgMatches, Command};
 use hgrep::grep::BufReadExt;
@@ -693,7 +691,7 @@ fn run(matches: ArgMatches) -> Result<bool> {
 
 fn main() {
     #[cfg(windows)]
-    if let Err(code) = ansi_term::enable_ansi_support() {
+    if let Err(code) = nu_ansi_term::enable_ansi_support() {
         eprintln!(
             "ANSI color support could not be enabled with error code {}",
             code
